#
# spec file for package ssh-pairing
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ssh-pairing
Version:        0.2
Release:        1.2
Summary:        Passwordless SSH key exchange through pairing
License:        GPL-2.0-or-later
URL:            https://github.com/Vogtinator/ssh-pairing
Source0:        %{name}-%{version}.tar.xz
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libssh)
Requires:       dialog
Requires:       hostname
Requires:       /usr/bin/ssh-keygen

%description
This tool allows to use pairing (like bluetooth, kde connect, ...) for exchanging public SSH keys, basically as alternative to ssh-copy-id.
With this, setting up SSH authentication is more user friendly, as the user's public key does not need to be transferred to the server manually.
It is arguably also more secure, as no passwords are involved, not even temporarily just to be able to ssh-copy-id.
This tool is design to be used as part of some CLI or TUI, but can also be used manually.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%files
%license LICENSE
%doc README.md
%{_sbindir}/ssh-pairing
%{_sbindir}/ssh-pairing-server

%changelog
* Fri Apr 12 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 0.2:
  * Ask for key import individually
  * Use SSH_STRING_FREE_CHAR instead of plain free
- Use mode="manual" in _service
* Wed Feb 14 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 0.1+git18:
  * Add Security Considerations section to README.md
  * Mention ssh-pairing prefix also in README.md
  * Add ssh-pairing prefix to the client success message
  * Clarify comment
  * Show ssh-pairing-server stderr on failure
  * Fail if kbd-interactive does not complete
* Fri Jan 26 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 0.1+git12:
  * Avoid unnecessary strlcpy
* Fri Jan 26 2024 Fabian Vogt <fvogt@suse.com>
- Update to version 0.1+git11:
  * Document ssh-pairing tool
  * Make it clear that the client message is important
  * No bogus output
  * Make shellcheck happy
  * Add ssh-pairing tool
  * Add a usage message
  * Shorten status message sent to the client
  * Print received keys immediately
  * Some README.md improvements
  * Fix indentation
  * Use NI_MAXHOST
* Thu Jan 18 2024 Fabian Vogt <fvogt@suse.com>
- Initial commit
